@@ -5,6 +5,7 @@ from __future__ import unicode_literals
 
 import argparse
 import sys
+from os import getenv
 
 from language_formatters_pre_commit_hooks.pre_conditions import rust_required
 from language_formatters_pre_commit_hooks.utils import run_command
@@ -23,10 +24,12 @@ def pretty_format_rust(argv=None):
     parser.add_argument('filenames', nargs='*', help='Filenames to fix')
     args = parser.parse_args(argv)
 
+    rustut_toolchain_version = getenv('RUST_TOOLCHAIN', 'nightly')
     # Check
-    _, output = run_command(
-        'cargo +nightly fmt  -- --check {}'.format(
-            ' '.join(args.filenames),
+    status_code, output = run_command(
+        'cargo +{} fmt -- --check {}'.format(
+            rustut_toolchain_version,
+            ' '.join(set(args.filenames)),
         ),
     )
     not_well_formatted_files = sorted(
@@ -43,12 +46,13 @@ def pretty_format_rust(argv=None):
         )
         if args.autofix:
             run_command(
-                'cargo +nightly fmt  -- {}'.format(
+                'cargo +{} fmt -- {}'.format(
+                    rustut_toolchain_version,
                     ' '.join(not_well_formatted_files),
                 ),
             )
 
-    return 1 if not_well_formatted_files else 0
+    return 1 if status_code != 0 or not_well_formatted_files else 0
 
 
 if __name__ == '__main__':
