@@ -11,6 +11,8 @@ from toml import dumps
 from toml import loads
 from toml import TomlDecodeError
 
+from language_formatters_pre_commit_hooks.utils import remove_trailing_whitespaces_and_set_new_line_ending
+
 
 def pretty_format_toml(argv=None):
     parser = argparse.ArgumentParser()
@@ -26,12 +28,14 @@ def pretty_format_toml(argv=None):
 
     status = 0
 
-    for toml_file in args.filenames:
+    for toml_file in set(args.filenames):
         with open(toml_file) as f:
             string_content = ''.join(f.readlines())
 
         try:
-            prettified_content = dumps(loads(string_content), preserve=True)
+            prettified_content = remove_trailing_whitespaces_and_set_new_line_ending(
+                dumps(loads(string_content)),
+            )
 
             if string_content != prettified_content:
                 print('File {} is not pretty-formatted'.format(toml_file))
